eventChannel property
The event channel used to receive events from the native overlay.
Implementation
@visibleForTesting
final eventChannel = const EventChannel('flutter_native_overlay_events');
The event channel used to receive events from the native overlay.
@visibleForTesting
final eventChannel = const EventChannel('flutter_native_overlay_events');