FlutterNativeOverlayPlatform class abstract

Inheritance
  • Object
  • PlatformInterface
  • FlutterNativeOverlayPlatform
Implementers

Constructors

FlutterNativeOverlayPlatform()
Constructs a FlutterNativeOverlayPlatform.

Properties

hashCode int
The hash code for this object.
no setterinherited
overlayEvents Stream<Map<String, dynamic>>
A stream of events from the native overlay (e.g. button clicks).
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

checkOverlayPermission() Future<bool>
endLiveActivity({String? activityId}) Future<bool>
getNativePadding() Future<Map<String, double>>
hideOverlay() Future<bool>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
requestOverlayPermission() Future<bool>
showOverlay({String? title, String? content, String? buttonText, NativeOverlayStyle? style, dynamic customImageBytes, dynamic avatarBytes, bool isDraggable = true, Duration? duration}) Future<bool>
startLiveActivity({required String title, required String content, double? progress}) Future<String?>
toString() String
A string representation of this object.
inherited
updateLiveActivity({required String activityId, String? title, String? content, double? progress}) Future<bool>

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance FlutterNativeOverlayPlatform
The default instance of FlutterNativeOverlayPlatform to use.
getter/setter pair