NativeAvatarStyle class
Styling for the optional avatar/leading image.
Constructors
- NativeAvatarStyle({double size = 48.0, double borderRadius = 24.0})
-
Creates a NativeAvatarStyle instance.
const
Properties
- borderRadius → double
-
The corner radius of the avatar image. Defaults to 24.0 (circular).
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- size → double
-
The size of the avatar/image in logical pixels. Defaults to 48.0.
final
Methods
-
copyWith(
{double? size, double? borderRadius}) → NativeAvatarStyle - Creates a copy of this avatar style with the given fields replaced.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> - Converts the avatar style to a map for the MethodChannel.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited