NativeButtonStyle class

Styling for the optional action button.

Constructors

NativeButtonStyle({bool showButton = false, String text = 'Close', Color backgroundColor = const Color(0xFF424242), Color textColor = const Color(0xFFFFFFFF), double fontSize = 14.0})
Creates a NativeButtonStyle instance.
const

Properties

backgroundColor → Color
The background color of the action button.
final
fontSize → double
The font size of the button text. Defaults to 14.0.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
showButton → bool
Whether to show the action button. Defaults to false.
final
text → String
The text to display on the action button.
final
textColor → Color
The text color of the action button.
final

Methods

copyWith({bool? showButton, String? text, Color? backgroundColor, Color? textColor, double? fontSize}) → NativeButtonStyle
Creates a copy of this button style with the given fields replaced.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, dynamic>
Converts the button style to a map for the MethodChannel.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited