NativeContentStyle class

Styling for the text content within the overlay.

Constructors

NativeContentStyle({Color titleColor = const Color(0xFFFFFFFF), double titleFontSize = 18.0, Color textColor = const Color(0xB3FFFFFF), double contentFontSize = 14.0})
Creates a NativeContentStyle instance.
const

Properties

contentFontSize → double
The font size of the content text. Defaults to 14.0.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
textColor → Color
The color of the main content text.
final
titleColor → Color
The color of the title text.
final
titleFontSize → double
The font size of the title text. Defaults to 18.0.
final

Methods

copyWith({Color? titleColor, double? titleFontSize, Color? textColor, double? contentFontSize}) → NativeContentStyle
Creates a copy of this content style with the given fields replaced.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, dynamic>
Converts the content style to a map for the MethodChannel.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited