NativeProgressStyle class

Styling for the auto-dismiss progress bar.

Constructors

NativeProgressStyle({bool showProgressBar = true, Color color = const Color(0xFF4CAF50), double height = 4.0})
Creates a NativeProgressStyle instance.
const

Properties

color → Color
The color of the progress bar.
final
hashCode → int
The hash code for this object.
no setterinherited
height → double
The height of the progress bar. Defaults to 4.0.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
showProgressBar → bool
Whether to show the progress bar. Only works if a duration is provided.
final

Methods

copyWith({bool? showProgressBar, Color? color, double? height}) → NativeProgressStyle
Creates a copy of this progress style with the given fields replaced.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, dynamic>
Converts the progress style to a map for the MethodChannel.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited