OverlayPosition enum

The position of the overlay on the screen.

Inheritance
Available extensions

Values

center → const OverlayPosition

Centered on the screen.

top → const OverlayPosition

Centered horizontally at the top of the screen.

bottom → const OverlayPosition

Centered horizontally at the bottom of the screen.

topLeft → const OverlayPosition

Top-left corner of the screen.

topRight → const OverlayPosition

Top-right corner of the screen.

bottomLeft → const OverlayPosition

Bottom-left corner of the screen.

bottomRight → const OverlayPosition

Bottom-right corner of the screen.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<OverlayPosition>
A constant List of the values in this enum, in order of their declaration.