MethodChannelFlutterNativeOverlay class

An implementation of FlutterNativeOverlayPlatform that uses method channels.

Inheritance

Properties

eventChannel EventChannel
The event channel used to receive events from the native overlay.
final
hashCode int
The hash code for this object.
no setterinherited
methodChannel MethodChannel
The method channel used to interact with the native platform.
final
overlayEvents Stream<Map<String, dynamic>>
A stream of events from the native overlay (e.g. button clicks).
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

checkOverlayPermission() Future<bool>
override
endLiveActivity({String? activityId}) Future<bool>
override
getNativePadding() Future<Map<String, double>>
override
hideOverlay() Future<bool>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
requestOverlayPermission() Future<bool>
override
showOverlay({String? title, String? content, String? buttonText, NativeOverlayStyle? style, dynamic customImageBytes, dynamic avatarBytes, bool isDraggable = true, Duration? duration}) Future<bool>
override
startLiveActivity({required String title, required String content, double? progress}) Future<String?>
override
toString() String
A string representation of this object.
inherited
updateLiveActivity({required String activityId, String? title, String? content, double? progress}) Future<bool>
override

Operators

operator ==(Object other) bool
The equality operator.
inherited