NativeContainerStyle class
Styling for the overlay's outer container.
Constructors
- NativeContainerStyle({Color backgroundColor = const Color(0xFF121212), OverlayShape shape = OverlayShape.rounded, double borderRadius = 16.0, OverlayPosition position = OverlayPosition.top, int xOffset = 0, int yOffset = 100, double? width, double? height, NativeEdgeInsets padding = const NativeEdgeInsets.all(16.0)})
-
Creates a NativeContainerStyle instance.
const
Properties
- backgroundColor → Color
-
The background color of the overlay card.
final
- borderRadius → double
-
The corner radius of the overlay card. Only used for OverlayShape.rounded.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- height → double?
-
Optional fixed height of the overlay in logical pixels.
final
- padding → NativeEdgeInsets
-
The padding inside the container. Defaults to 16.0 on all sides.
final
- position → OverlayPosition
-
The gravity/position of the overlay on the screen.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- shape → OverlayShape
-
The shape of the overlay container. Defaults to OverlayShape.rounded.
final
- width → double?
-
Optional fixed width of the overlay in logical pixels.
final
- xOffset → int
-
The horizontal offset from the defined position.
final
- yOffset → int
-
The vertical offset from the defined position.
final
Methods
-
copyWith(
{Color? backgroundColor, OverlayShape? shape, double? borderRadius, OverlayPosition? position, int? xOffset, int? yOffset, double? width, double? height, NativeEdgeInsets? padding}) → NativeContainerStyle - Creates a copy of this container style with the given fields replaced.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> - Converts the container style to a map for the MethodChannel.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited