NativeEdgeInsets class

A simplified version of EdgeInsets for passing padding to the native layer.

Constructors

NativeEdgeInsets.all(double value)
Creates offsets where all sides are the same value.
const
NativeEdgeInsets.only({double left = 0.0, double top = 0.0, double right = 0.0, double bottom = 0.0})
Creates offsets where only the specified sides have non-zero values.
const
NativeEdgeInsets.symmetric({double horizontal = 0.0, double vertical = 0.0})
Creates offsets with symmetrical horizontal and vertical values.
const

Properties

bottom double
Padding on the bottom side.
final
hashCode int
The hash code for this object.
no setterinherited
left double
Padding on the left side.
final
Padding on the right side.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
top double
Padding on the top side.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited