NativeOverlayStyle class
Defines the visual styling for the native overlay.
Constructors
- NativeOverlayStyle({NativeContainerStyle container = const NativeContainerStyle(), NativeContentStyle content = const NativeContentStyle(), NativeButtonStyle button = const NativeButtonStyle(), NativeAvatarStyle avatar = const NativeAvatarStyle(), NativeProgressStyle progress = const NativeProgressStyle()})
-
Creates a NativeOverlayStyle instance.
const
Properties
- avatar → NativeAvatarStyle
-
Avatar/Leading image styling.
final
-
Action button styling.
final
- container → NativeContainerStyle
-
Container styling (background, shape, position, size, padding).
final
- content → NativeContentStyle
-
Text styling (colors, font sizes).
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- progress → NativeProgressStyle
-
Progress bar styling for auto-dismiss overlays.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{NativeContainerStyle? container, NativeContentStyle? content, NativeButtonStyle? button, NativeAvatarStyle? avatar, NativeProgressStyle? progress}) → NativeOverlayStyle - Creates a copy of this style with the given fields replaced.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> - Converts the style to a map for the MethodChannel.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited